=============
Release Notes
=============

This section provides an overview of the key features and bug fixes introduced in each version of pyquations. It offers a quick summary of the most important updates, helping you stay up to date with the latest improvements and changes.

.. tip::

   Each release includes the full commit history along with more detailed information, which can be explored further in the `GitHub Releases <https://github.com/mitchell-gottlieb/pyquations/releases>`_!

.. toctree::
   :maxdepth: 2
   :glob:
   :hidden:
   :reversed:

   *